==> unicornhat-2.0.7.tar.gz: unicornhat-2.0.7/setup.py <==
#!/usr/bin/env python
"""
Copyright (c) 2014 Pimoroni
Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the "Software"), to deal in
the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
of the Software, and to permit persons to whom the Software is furnished to do
so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

classifiers = ['Development Status :: 5 - Production/Stable',
               'Operating System :: POSIX :: Linux',
               'License :: OSI Approved :: MIT License',
               'Intended Audience :: Developers',
               'Programming Language :: Python :: 2.6',
               'Programming Language :: Python :: 2.7',
               'Programming Language :: Python :: 3',
               'Topic :: Software Development',
               'Topic :: System :: Hardware']

setup(
    name        = 'unicornhat',
    version     = '2.0.7',
    author      = 'Philip Howard',
    author_email= 'phil@pimoroni.com',
    description = """The Python library for UnicornHat a matrix of 64, eye-burning, ws2812 LEDs!""",
    long_description = open('README').read() + open('CHANGELOG').read(),
    license     = 'MIT',
    keywords    = 'Raspberry Pi Unicorn HAT',
    url         = 'http://shop.pimoroni.com',
    classifiers = classifiers,
    py_modules  = [ 'unicornhat' ],
    install_requires = ['rpi_ws281x >= 2.0.0'],
)

==> unicornhat-2.1.0.tar.gz: unicornhat-2.1.0/setup.py <==
#!/usr/bin/env python
"""
Copyright (c) 2014 Pimoroni
Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the "Software"), to deal in
the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
of the Software, and to permit persons to whom the Software is furnished to do
so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

classifiers = ['Development Status :: 5 - Production/Stable',
               'Operating System :: POSIX :: Linux',
               'License :: OSI Approved :: MIT License',
               'Intended Audience :: Developers',
               'Programming Language :: Python :: 2.6',
               'Programming Language :: Python :: 2.7',
               'Programming Language :: Python :: 3',
               'Topic :: Software Development',
               'Topic :: System :: Hardware']

setup(
    name        = 'unicornhat',
    version     = '2.1.0',
    author      = 'Philip Howard',
    author_email= 'phil@pimoroni.com',
    description = """The Python library for UnicornHAT/pHAT a matrix of 64 or 32, eye-burning, ws2812 LEDs!""",
    long_description = open('README').read() + open('CHANGELOG').read(),
    license     = 'MIT',
    keywords    = 'Raspberry Pi Unicorn HAT',
    url         = 'http://shop.pimoroni.com',
    classifiers = classifiers,
    py_modules  = [ 'unicornhat' ],
    install_requires = ['rpi_ws281x >= 2.0.0'],
)
